package com.vp.plugin.sample.elementcolor.actions;

import java.awt.Color;

import com.vp.plugin.ApplicationManager;
import com.vp.plugin.action.VPAction;
import com.vp.plugin.action.VPActionController;
import com.vp.plugin.diagram.IDiagramElement;
import com.vp.plugin.diagram.IDiagramUIModel;
import com.vp.plugin.diagram.IShapeUIModel;
import com.vp.plugin.diagram.format.IFillColor;
import com.vp.plugin.model.IProjectFillColorModel;

public class ElementColorActionControl implements VPActionController {
	
	private static String ACTION_SET_SOLID_COLOR = "set_solid_color";
	private static String ACTION_SET_GRADIENT_COLOR = "set_gradient_color";
	private static String ACTION_SET_TRANSPARENT = "set_transparent";	
	
	@Override
	public void performAction(VPAction arg0) {
		// Obtain the active diagram in application
		IDiagramUIModel diagram = ApplicationManager.instance().getDiagramManager().getActiveDiagram();
		// Retrieve all elements on diagram into array		
		IDiagramElement[] shapes = diagram.toDiagramElementArray();
		for (IDiagramElement shape: shapes) {
			// Process if it is a shape but not a connector
			if (shape instanceof IShapeUIModel) {
				// Cast it to IShapeUIModeland and retrieve its IFillColor model.  
				IShapeUIModel shapeModel = (IShapeUIModel) shape;
				IFillColor fillColor = shapeModel.getFillColor();
				// Set the shape to solid magenta color and non transparent 
				if (ACTION_SET_SOLID_COLOR.equals(arg0.getActionId())) {
					fillColor.setType(IFillColor.TYPE_SOLID);
					fillColor.setColor1(Color.MAGENTA);
					fillColor.setTransparency(0);
				// Set the shape to gradient color magenta + yellow, 
				// from north east to south west direction and non transparent
				} else if (ACTION_SET_GRADIENT_COLOR.equals(arg0.getActionId())) {
					fillColor.setType(IFillColor.TYPE_GRADIENT);
					fillColor.setGradientStyle(IProjectFillColorModel.FILL_COLOR_GRADIENT_STYLE_DNORTHEAST_LSOUTHWEST);
					fillColor.setColor1(Color.YELLOW);
					fillColor.setColor2(Color.MAGENTA);
					fillColor.setTransparency(0);
				// Set the shape to 50% transparent
				} else if (ACTION_SET_TRANSPARENT.equals(arg0.getActionId())) {
					fillColor.setTransparency(50);
				}
			}
		}
	}

	@Override
	public void update(VPAction arg0) {
		// TODO Auto-generated method stub
		
	}

}
